@@ -1,9 +1,7 @@
-import pydantic
+from pydantic import BaseModel
 
-
-class Token(pydantic.BaseModel):
+class Token(BaseModel):
     access_token: str
     refresh_token: str
     token_type: str
-    expires_in: int
-    expires_at: float
\ No newline at end of file
+    expires_in: int
\ No newline at end of file
