@@ -1,8 +1,8 @@
-import asyncio
 from dataclasses import dataclass
-from typing import Coroutine
 from etsy_apiv3.utils import EtsySession, Response
 from etsy_apiv3.models import Receipt, ReceiptType, Transaction
+from typing import Union
+from etsy_apiv3.utils.EtsyOauth2Session import EtsyOauth2Session
 
 @dataclass
 class ReceiptResource:
@@ -10,7 +10,7 @@ class ReceiptResource:
     Receipt Resource is the utility class to get receipts from Etsy
     
     """
-    session: EtsySession
+    session: Union[EtsySession, EtsyOauth2Session]
     
     def get_receipts(self, shop_id: int, limit=25, offset=0, type: ReceiptType = ReceiptType.UNSHIPPED, **kwargs) -> Response[Receipt]:
         """
