@@ -1,12 +1,13 @@
 from dataclasses import dataclass
 #from etsy_apiv3.utils.APIV3 import EtsyAuth
 from async_oauthlib import OAuth2Session as AsyncOAuth2Session
-from ..utils import Response, EtsySession
+from etsy_apiv3.utils import Response, EtsySession, EtsyOauth2Session
 from ..models.ReviewModel import Review
+from typing import Union
 
 @dataclass
 class ReviewResource:
-    session: EtsySession
+    session: Union[EtsySession, EtsyOauth2Session]
     
     def get_reviews_by_listing_id(self, listing_id: int, limit: int = 25, offset: int = 0):
         
