@@ -1,6 +1,6 @@
 from dataclasses import dataclass
-from typing import List, Optional
-from etsy_apiv3.utils import EtsySession, Response
+from typing import List, Optional, Union
+from etsy_apiv3.utils import EtsySession, Response, EtsyOauth2Session
 from etsy_apiv3.models import ShippingCarrier, ShippingProfile, ShippingProfileDestination, ShippingProfileUpgrade
 
 @dataclass
@@ -9,7 +9,7 @@ class ShippingResource:
     Shop Resource Of Etsy Api V3.
 
     """
-    session: EtsySession
+    session: Union[EtsySession, EtsyOauth2Session]
     
     def get_shipping_carriers(self, origin_country_iso: str) -> Response[ShippingCarrier]:
         endpoint = "shipping-carriers"
