@@ -1,7 +1,7 @@
 from dataclasses import dataclass
-from typing import List, Optional
+from typing import List, Optional, Union
 from etsy_apiv3.models import ProductionPartner, Shop, ShopSection
-from etsy_apiv3.utils import EtsySession, Response
+from etsy_apiv3.utils import EtsySession, Response, EtsyOauth2Session
 
 @dataclass
 class ShopResource:
@@ -9,7 +9,7 @@ class ShopResource:
     Shop Resource Of Etsy Api V3.
 
     """
-    session: EtsySession
+    session: Union[EtsySession, EtsyOauth2Session]
     
     def get_shop_by_id(self, shop_id: int):
         """
